<?php
/**
 * SimpleBlue functions and definitions
 *
 * The first function, simpleblue_setup(), sets up the theme by registering support
 * for various features in WordPress, such as post thumbnails, navigation menus, and the like.
 *
 * @package WordPress
 * @subpackage SimpleBlue
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 584;

/**
 * Tell WordPress to run simpleblue_setup() when the 'after_setup_theme' hook is run.
 */
add_action( 'after_setup_theme', 'simpleblue_setup' );

if ( ! function_exists( 'simpleblue_setup' ) ):
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * To override simpleblue_setup() in a child theme, add your own simpleblue_setup to your child theme's
 * functions.php file.
 *
 *
 */
function simpleblue_setup() {

	/* Make SimpleBlue available for translation.
	 * Translations can be added to the /languages/ directory.
	 * If you're building a theme based on SimpleBlue, use a find and replace
	 * to change 'simpleblue' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'simpleblue', TEMPLATEPATH . '/languages' );

	$locale = get_locale();
	$locale_file = TEMPLATEPATH . "/languages/$locale.php";
	if ( is_readable( $locale_file ) )
		require_once( $locale_file );

	// This theme uses Featured Images (also known as post thumbnails) for per-post/per-page Custom Header images
	add_theme_support( 'post-thumbnails' );

	// Add default posts and comments RSS feed links to <head>.
	add_theme_support( 'automatic-feed-links' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', __( 'Primary Menu', 'simpleblue' ) );

}
endif; // simpleblue_setup


/**
 * Sets the post excerpt length to 40 words.
 *
 * To override this length in a child theme, remove the filter and add your own
 * function tied to the excerpt_length filter hook.
 */
function simpleblue_excerpt_length( $length ) {
	return 60;
}
add_filter( 'excerpt_length', 'simpleblue_excerpt_length' );

/**
 * Returns a "Continue Reading" link for excerpts
 */
function simpleblue_continue_reading_link() {
	return ' <a href="'. esc_url( get_permalink() ) . '">' . __( 'Continue reading &hellip;', 'simpleblue' ) . '</a>';
}


/**
 * Replaces "[...]" (appended to automatically generated excerpts) with an ellipsis and simpleblue_continue_reading_link().
 *
 * To override this in a child theme, remove the filter and add your own
 * function tied to the excerpt_more filter hook.
 */
function simpleblue_auto_excerpt_more( $more ) {
	return ' &hellip;' . simpleblue_continue_reading_link();
}
add_filter( 'excerpt_more', 'simpleblue_auto_excerpt_more' );

/**
 * Adds a pretty "Continue Reading" link to custom post excerpts.
 *
 * To override this link in a child theme, remove the filter and add your own
 * function tied to the get_the_excerpt filter hook.
 */
function simpleblue_custom_excerpt_more( $output ) {
	if ( has_excerpt() && ! is_attachment() ) {
		$output .= simpleblue_continue_reading_link();
	}
	return $output;
}
add_filter( 'get_the_excerpt', 'simpleblue_custom_excerpt_more' );

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */
function simpleblue_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'simpleblue_page_menu_args' );

/**
 * Register our sidebars and widgetized areas. Also register the default Epherma widget.
 *
 * @since SimpleBlue 4.0.0
 */
function simpleblue_widgets_init() {

	register_sidebar( array(
		'name' => __( 'Main Sidebar', 'simpleblue' ),
		'id' => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Left Sidebar', 'simpleblue' ),
		'id' => 'sidebar-2',
		'description' => __( 'The left field of two columns sidebar', 'simpleblue' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => __( 'Right Sidebar', 'simpleblue' ),
		'id' => 'sidebar-2-2',
		'description' => __( 'The right field of two columns sidebar', 'simpleblue' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Footer Area One', 'simpleblue' ),
		'id' => 'sidebar-3',
		'description' => __( 'An optional widget area for your site footer', 'simpleblue' ),
		'before_widget' => '<aside id="%1$s" class="foot-widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="foot-widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Footer Area Two', 'simpleblue' ),
		'id' => 'sidebar-4',
		'description' => __( 'An optional widget area for your site footer', 'simpleblue' ),
		'before_widget' => '<aside id="%1$s" class="foot-widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="foot-widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Footer Area Three', 'simpleblue' ),
		'id' => 'sidebar-5',
		'description' => __( 'An optional widget area for your site footer', 'simpleblue' ),
		'before_widget' => '<aside id="%1$s" class="foot-widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="foot-widget-title">',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'simpleblue_widgets_init' );

/**
 * Count the number of footer sidebars to enable dynamic classes for the footer
 */
function simpleblue_footer_sidebar_class() {
	$count = 0;

	if ( is_active_sidebar( 'sidebar-3' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-4' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-5' ) )
		$count++;

	$class = '';

	switch ( $count ) {
		case '1':
			$class = 'one';
			break;
		case '2':
			$class = 'two';
			break;
		case '3':
			$class = 'three';
			break;
	}

	if ( $class )
		echo 'class="' . $class . '"';
}

/**
 * Display navigation to next/previous pages when applicable
 */
function simpleblue_content_nav( $nav_id ) {
	global $wp_query;

	if ( $wp_query->max_num_pages > 1 ) : ?>
		<nav id="<?php echo $nav_id; ?>">
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'simpleblue' ) ); ?></div>
			<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'simpleblue' ) ); ?></div>
		</nav><!-- #nav-above -->
	<?php endif;
}


/**
 * Return the URL for the first link found in the post content.
 *
 * @return string|bool URL or false when no link is present.
 */
function simpleblue_url_grabber() {
	if ( ! preg_match( '/<a\s[^>]*?href=[\'"](.+?)[\'"]/is', get_the_content(), $matches ) )
		return false;

	return esc_url_raw( $matches[1] );
}

if ( ! function_exists( 'simpleblue_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own simpleblue_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 */
function simpleblue_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
<li class="post pingback">
  <p>
    <?php _e( 'Pingback:', 'simpleblue' ); ?>
    <?php comment_author_link(); ?>
    <?php edit_comment_link( __( 'Edit', 'simpleblue' ), '<span class="edit-link">', '</span>' ); ?>
  </p>
  <?php
			break;
		default :
	?>
<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
  <article id="comment-<?php comment_ID(); ?>" class="comment">
    <footer class="comment-meta">
      <div class="comment-author vcard">
        <?php
						$avatar_size = 68;
						if ( '0' != $comment->comment_parent )
							$avatar_size = 39;

						echo get_avatar( $comment, $avatar_size );

						/* translators: 1: comment author, 2: date and time */
						printf( __( '%1$s on %2$s <span class="says">said:</span>', 'simpleblue' ),
							sprintf( '<span class="fn">%s</span>', get_comment_author_link() ),
							sprintf( '<a href="%1$s"><time pubdate datetime="%2$s">%3$s</time></a>',
								esc_url( get_comment_link( $comment->comment_ID ) ),
								get_comment_time( 'c' ),
								/* translators: 1: date, 2: time */
								sprintf( __( '%1$s at %2$s', 'simpleblue' ), get_comment_date(), get_comment_time() )
							)
						);
					?>
        <?php edit_comment_link( __( 'Edit', 'simpleblue' ), '<span class="edit-link">', '</span>' ); ?>
      </div>
      <!-- .comment-author .vcard -->
      
      <?php if ( $comment->comment_approved == '0' ) : ?>
      <em class="comment-awaiting-moderation">
      <?php _e( 'Your comment is awaiting moderation.', 'simpleblue' ); ?>
      </em> <br />
      <?php endif; ?>
    </footer>
    <div class="comment-content">
      <?php comment_text(); ?>
    </div>
    <div class="reply">
      <?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply <span>&darr;</span>', 'simpleblue' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
    </div>
    <!-- .reply --> 
  </article>
  <!-- #comment-## -->
  
  <?php
			break;
	endswitch;
}
endif; // ends check for simpleblue_comment()

?>
